==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/cy-GB/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Cadarnahu Dileu Nifer o Asedau',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Adolygwch yr asedau ar gyfer dileu isod. Ar ôl eu dileu, gellir adfer yr asedau hyn, ond ni fyddant yn gysylltiedig mwyach ag unrhyw ddefnyddwyr y maent wedi\'u neilltuo iddynt ar hyn o bryd.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Rydych am dileu :asset_count assets.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Diweddaru Nifer o Asedau',
    'bulk_update_help'	=> 'Mae\'r ffurflen hon yn caniatáu ichi ddiweddaru nifer o asedau ar unwaith. Llenwch y meysydd sydd angen i chi eu newid yn unig. Bydd unrhyw bwlch a adewir yn wag yn aros yr un fath. ',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Wedi aseinio i',
    'checkout_date'		=> 'Dyddiad allan',
    'checkin_date'		=> 'Dyddian i mewn',
    'checkout_to'		=> 'Dynodi i',
    'cost'				=> 'Cost pwrcasu',
    'create'			=> 'Creu Ased',
    'date'				=> 'Dyddiad Pwrcasu',
    'depreciation'	    => 'Dibrisiant',
    'depreciates_on'	=> 'Dibrisio Ar',
    'default_location'	=> 'Lleoliad diofyn',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Dyddiad DB',
    'eol_rate'			=> 'Cyfradd DB',
    'expected_checkin'  => 'Dyddiad disgwl i mewn',
    'expires'			=> 'Dod i ben',
    'fully_depreciated'	=> 'Dibrisiant Llwyr',
    'help_checkout'		=> 'Os ydych chi am aseinio\'r ased hwn ar unwaith, dewiswch "Barod i\'w Ddefnyddio" o\'r rhestr statws uchod. ',
    'mac_address'		=> 'Cyfeiriad MAC',
    'manufacturer'		=> 'Gwneuthyrwr',
    'model'				=> 'Model',
    'months'			=> 'misoedd',
    'name'				=> 'Enw Ased',
    'notes'				=> 'Nodiadau',
    'order'				=> 'Rhif Archeb',
    'qr'				=> 'Côd QR',
    'requestable'		=> 'Gellir ddefnyddwyr gwneud cais am yr ased yma',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Dewis Math o Statws',
    'serial'			=> 'Serial',
    'status'			=> 'Statws',
    'tag'				=> 'Tag Ased',
    'update'			=> 'Diweddaru Ased',
    'warranty'			=> 'Warant',
        'warranty_expires'		=> 'Warrant yn dod I ben',
    'years'				=> 'blynyddoedd',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/cy-GB/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Cadarnahu Dileu Nifer o Asedau',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Adolygwch yr asedau ar gyfer dileu isod. Ar ôl eu dileu, gellir adfer yr asedau hyn, ond ni fyddant yn gysylltiedig mwyach ag unrhyw ddefnyddwyr y maent wedi\'u neilltuo iddynt ar hyn o bryd.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Rydych am dileu :asset_count assets.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Diweddaru Nifer o Asedau',
    'bulk_update_help'	=> 'Mae\'r ffurflen hon yn caniatáu ichi ddiweddaru nifer o asedau ar unwaith. Llenwch y meysydd sydd angen i chi eu newid yn unig. Bydd unrhyw bwlch a adewir yn wag yn aros yr un fath. ',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Wedi aseinio i',
    'checkout_date'		=> 'Dyddiad allan',
    'checkin_date'		=> 'Dyddian i mewn',
    'checkout_to'		=> 'Dynodi i',
    'cost'				=> 'Cost pwrcasu',
    'create'			=> 'Creu Ased',
    'date'				=> 'Dyddiad Pwrcasu',
    'depreciation'	    => 'Dibrisiant',
    'depreciates_on'	=> 'Dibrisio Ar',
    'default_location'	=> 'Lleoliad diofyn',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Dyddiad DB',
    'eol_rate'			=> 'Cyfradd DB',
    'expected_checkin'  => 'Dyddiad disgwl i mewn',
    'expires'			=> 'Dod i ben',
    'fully_depreciated'	=> 'Dibrisiant Llwyr',
    'help_checkout'		=> 'Os ydych chi am aseinio\'r ased hwn ar unwaith, dewiswch "Barod i\'w Ddefnyddio" o\'r rhestr statws uchod. ',
    'mac_address'		=> 'Cyfeiriad MAC',
    'manufacturer'		=> 'Gwneuthyrwr',
    'model'				=> 'Model',
    'months'			=> 'misoedd',
    'name'				=> 'Enw Ased',
    'notes'				=> 'Nodiadau',
    'order'				=> 'Rhif Archeb',
    'qr'				=> 'Côd QR',
    'requestable'		=> 'Gellir ddefnyddwyr gwneud cais am yr ased yma',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Dewis Math o Statws',
    'serial'			=> 'Serial',
    'status'			=> 'Statws',
    'tag'				=> 'Tag Ased',
    'update'			=> 'Diweddaru Ased',
    'warranty'			=> 'Warant',
        'warranty_expires'		=> 'Warrant yn dod I ben',
    'years'				=> 'blynyddoedd',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];
